ExecutionResult class

Result of executing a single action.

Constructors

ExecutionResult({required ActionDescriptor action, required bool success, String? error})

Properties

action ActionDescriptor
The action that was attempted.
final
error String?
Error message if execution failed.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
Whether execution succeeded.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited