AgentState class
Mutable state of the running AgentCore.
Constructors
- AgentState({AgentStatus status = AgentStatus.idle, int stepCount = 0, String? lastError})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastError ↔ String?
-
Last error message, if any.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ AgentStatus
-
Current execution status.
getter/setter pair
- stepCount ↔ int
-
Number of loop iterations completed.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited